@@ -585,7 +585,7 @@ static bool SaveBufferCallback(const char *dest_filename, void *param, NewLineMo
     if (bytes_written != BufferSize(output_buffer))
     {
         Log(LOG_LEVEL_ERR,
-            "Error writing to output file '%s' when writing. %zu bytes written but expected %u. (fclose: %s)",
+            "Error writing to output file '%s' when writing. %zu bytes written but expected %zu. (fclose: %s)",
             dest_filename, bytes_written, BufferSize(output_buffer), GetErrorStr());
         fclose(fp);
         return false;
@@ -675,7 +675,13 @@ static PromiseResult RenderTemplateMustache(EvalContext *ctx, const Promise *pp,
     }
     else
     {
-        cfPS(ctx, LOG_LEVEL_ERR, PROMISE_RESULT_FAIL, pp, &a, "Error rendering mustache template '%s'", a.edit_template);
+        /* Use `edit_template` attribute when template method is "mustache".
+         * Use `edit_template_string` attribute when template method is
+         * "inline_mustache".
+         */
+        char *tmpl = StringEqual(attr->template_method, "mustache")
+                   ? attr->edit_template : attr->edit_template_string;
+        cfPS(ctx, LOG_LEVEL_ERR, PROMISE_RESULT_FAIL, pp, &a, "Error rendering mustache template '%s'", tmpl);
         result = PromiseResultUpdate(result, PROMISE_RESULT_FAIL);
         BufferDestroy(output_buffer);
         JsonDestroy(destroy_this);
