@@ -38,6 +38,7 @@
 #include <man.h>
 #include <signals.h>
 #include <string_lib.h>
+#include <file_lib.h>           /* FILE_SEPARATOR */
 #include <cleanup.h>
 
 #include <cf-key-functions.h>
@@ -145,17 +146,24 @@ int main(int argc, char *argv[])
     EvalContext *ctx = EvalContextNew();
     GenericAgentConfigApply(ctx, config);
 
-    GenericAgentDiscoverContext(ctx, config);
+    const char *program_invocation_name = argv[0];
+    const char *last_dir_sep = strrchr(program_invocation_name, FILE_SEPARATOR);
+    const char *program_name = (last_dir_sep != NULL ? last_dir_sep + 1 : program_invocation_name);
+    GenericAgentDiscoverContext(ctx, config, program_name);
 
     if (SHOWHOSTS)
     {
         SetupSignalsForCfKey(handleShowKeysSignal);
         ShowLastSeenHosts(!NO_TRUNCATE);
-        return 0;
+        GenericAgentFinalize(ctx, config);
+        CallCleanupFunctions();
+        return EXIT_SUCCESS;
     }
 
     if (print_digest_arg)
     {
+        GenericAgentFinalize(ctx, config);
+        CallCleanupFunctions();
         return PrintDigest(print_digest_arg);
     }
 
@@ -182,18 +190,22 @@ int main(int argc, char *argv[])
             if (status == 0 || status == 1)
             {
                 Log (LOG_LEVEL_VERBOSE,
-                    "Forced removal of entry '%s' was successful",
-                    remove_keys_host);
-                return 0;
+                     "Forced removal of entry '%s' was successful",
+                     remove_keys_host);
+                status = EXIT_SUCCESS;
             }
         }
+        GenericAgentFinalize(ctx, config);
+        CallCleanupFunctions();
         return status;
     }
 
     if(LICENSE_INSTALL)
     {
         bool success = LicenseInstall(LICENSE_SOURCE);
-        return success ? 0 : 1;
+        GenericAgentFinalize(ctx, config);
+        CallCleanupFunctions();
+        return success ? EXIT_SUCCESS : EXIT_FAILURE;
     }
 
     if (trust_key_arg != NULL)
@@ -214,6 +226,8 @@ int main(int argc, char *argv[])
         bool ret = TrustKey(filename, ipaddr, username);
 
         free(arg);
+        GenericAgentFinalize(ctx, config);
+        CallCleanupFunctions();
         return ret ? EXIT_SUCCESS : EXIT_FAILURE;
     }
 
@@ -237,6 +251,7 @@ int main(int argc, char *argv[])
 
     GenericAgentFinalize(ctx, config);
 
+    CallCleanupFunctions();
     return ret ? EXIT_SUCCESS : EXIT_FAILURE;
 }
 
@@ -281,6 +296,7 @@ static GenericAgentConfig *CheckOpts(int argc, char **argv)
                 GenericAgentWriteVersion(w);
                 FileWriterDetach(w);
             }
+            GenericAgentConfigDestroy(config);
             DoCleanupAndExit(EXIT_SUCCESS);
 
         case 'v':
@@ -327,6 +343,7 @@ static GenericAgentConfig *CheckOpts(int argc, char **argv)
 
         case 'h':
             PrintHelp();
+            GenericAgentConfigDestroy(config);
             DoCleanupAndExit(EXIT_SUCCESS);
 
         case 'M':
@@ -339,12 +356,14 @@ static GenericAgentConfig *CheckOpts(int argc, char **argv)
                              NULL, false,
                              false);
                 FileWriterDetach(out);
+                GenericAgentConfigDestroy(config);
                 DoCleanupAndExit(EXIT_SUCCESS);
             }
 
         case 'C':
             if (!GenericAgentConfigParseColor(config, optarg))
             {
+                GenericAgentConfigDestroy(config);
                 DoCleanupAndExit(EXIT_FAILURE);
             }
             break;
@@ -359,6 +378,7 @@ static GenericAgentConfig *CheckOpts(int argc, char **argv)
 
         default:
             PrintHelp();
+            GenericAgentConfigDestroy(config);
             DoCleanupAndExit(EXIT_FAILURE);
 
         }
@@ -368,6 +388,7 @@ static GenericAgentConfig *CheckOpts(int argc, char **argv)
     {
         PrintHelp();
         Log(LOG_LEVEL_ERR, "--no-truncate / -N option is only for --show-hosts / -s");
+        GenericAgentConfigDestroy(config);
         DoCleanupAndExit(EXIT_FAILURE);
     }
 
