@@ -33,6 +33,7 @@
 #include <man.h>
 #include <bootstrap.h>
 #include <string_lib.h>
+#include <file_lib.h>                                     /* FILE_SEPARATOR */
 #include <loading.h>
 #include <regex.h>                                        /* CompileRegex */
 #include <match_scope.h>
@@ -135,7 +136,11 @@ int main(int argc, char *argv[])
     EvalContext *ctx = EvalContextNew();
     GenericAgentConfigApply(ctx, config);
 
-    GenericAgentDiscoverContext(ctx, config);
+    const char *program_invocation_name = argv[0];
+    const char *last_dir_sep = strrchr(program_invocation_name, FILE_SEPARATOR);
+    const char *program_name = (last_dir_sep != NULL ? last_dir_sep + 1 : program_invocation_name);
+    GenericAgentDiscoverContext(ctx, config, program_name);
+
     Policy *policy = LoadPolicy(ctx, config);
     if (!policy)
     {
@@ -497,5 +502,6 @@ GenericAgentConfig *CheckOpts(int argc, char **argv)
         DoCleanupAndExit(EXIT_FAILURE);
     }
 
+    CallCleanupFunctions();
     return config;
 }
