@@ -732,12 +732,12 @@ static char *IncrementIPaddress(const char *ip_str)
     int step = 1;
     char *last_dot = strrchr(ip_str, '.');
     assert(last_dot != NULL);   /* the doc comment says there must be dots! */
-    if (StringSafeEqual(last_dot + 1, "255"))
+    if (StringEqual(last_dot + 1, "255"))
     {
         /* avoid the network address (ending with 0) */
         step = 2;
     }
-    else if (StringSafeEqual(last_dot + 1, "254"))
+    else if (StringEqual(last_dot + 1, "254"))
     {
         /* avoid the broadcast address and the network address */
         step = 3;
@@ -820,6 +820,7 @@ int main(int argc, char *argv[])
 
     if (failure)
     {
+        CallCleanupFunctions();
         return EXIT_FAILURE;
     }
 
@@ -837,5 +838,6 @@ int main(int argc, char *argv[])
         CFTestD_ConfigDestroy(thread_configs[i]);
     }
 
+    CallCleanupFunctions();
     return failure ? EXIT_FAILURE : EXIT_SUCCESS;
 }
