@@ -1,5 +1,5 @@
 /*
-  Copyright 2020 Northern.tech AS
+  Copyright 2021 Northern.tech AS
 
   This file is part of CFEngine 3 - written and maintained by Northern.tech AS.
 
@@ -252,6 +252,7 @@ static Mustache NextTag(const char *input,
         break;
     case '{':
         extra_end = "}";
+        // fall through
     case '&':
         ret.type = TAG_TYPE_VAR_UNESCAPED;
         ret.content++;
@@ -302,7 +303,9 @@ static Mustache NextTag(const char *input,
         ret.content_len--;
     }
 
-    while (ret.content[ret.content_len - 1] == ' ' || ret.content[ret.content_len - 1] == '\t')
+    while (ret.content_len > 0
+           && (ret.content[ret.content_len - 1] == ' '
+               || ret.content[ret.content_len - 1] == '\t'))
     {
         ret.content_len--;
     }
@@ -490,6 +493,18 @@ static bool RenderVariable(Buffer *out,
             // because we return false earlier otherwise
             return RenderVariablePrimitive(out, var, escape, json_key);
         }
+        else if (item_mode)
+        {
+            // This can happen in 2 cases:
+            // if you try to use {{.}} on the top element (without iterating)
+            // if you try to use {{.}} while iterating and the current element is a container
+            // In both cases we want to give an error(warning) since this is not clear in the
+            // mustache spec
+            Log(LOG_LEVEL_WARNING,
+                "{{.}} mustache tag cannot expand a container without specifying conversion"
+                " - consider {{$.}} or {{%%.}}");
+            return false;
+        }
     }
 
     assert(false);
@@ -568,8 +583,8 @@ static bool IsKeyExtensionVar(TagType tag_type, const char *tag_start,
         /* the special case of unescaped form using {{{@}}} iff "{{" and "}}" are
          * used as delimiters */
         if ((delim_start_len == 2) && (delim_end_len == 2) &&
-            StringSafeEqual(delim_start, "{{") &&
-            StringSafeEqual(delim_end, "}}") &&
+            StringEqual(delim_start, "{{") &&
+            StringEqual(delim_end, "}}") &&
             StringStartsWith(tag_start, "{{{@}}}"))
         {
             return true;
@@ -752,25 +767,23 @@ static bool Render(Buffer *out, const char *start, const char *input, Seq *hash_
                 switch (JsonGetElementType(var))
                 {
                 case JSON_ELEMENT_TYPE_PRIMITIVE:
-                    switch (JsonGetPrimitiveType(var))
+                    if (JsonGetPrimitiveType(var) == JSON_PRIMITIVE_TYPE_BOOL)
                     {
-                    case JSON_PRIMITIVE_TYPE_BOOL:
+                        bool skip = skip_content || (!JsonPrimitiveGetAsBool(var) ^ (tag.type == TAG_TYPE_INVERTED));
+
+                        const char *cur_section_end = NULL;
+                        if (!Render(out, start, input, hash_stack, NULL, delim_start, delim_start_len, delim_end, delim_end_len,
+                                    skip, cur_section, &cur_section_end))
                         {
-                            bool skip = skip_content || (!JsonPrimitiveGetAsBool(var) ^ (tag.type == TAG_TYPE_INVERTED));
-
-                            const char *cur_section_end = NULL;
-                            if (!Render(out, start, input, hash_stack, NULL, delim_start, delim_start_len, delim_end, delim_end_len,
-                                        skip, cur_section, &cur_section_end))
-                            {
-                                free(cur_section);
-                                return false;
-                            }
                             free(cur_section);
-                            input = cur_section_end;
+                            return false;
                         }
+                        free(cur_section);
+                        input = cur_section_end;
                         continue;
-
-                    default:
+                    }
+                    else
+                    {
                         Log(LOG_LEVEL_WARNING, "Mustache sections can only take a boolean or a container (array or map) value, but section '%s' isn't getting one of those.",
                             cur_section);
                         free(cur_section);
@@ -800,10 +813,10 @@ static bool Render(Buffer *out, const char *start, const char *input, Seq *hash_
                                 free(cur_section);
                                 break;
                             }
-                            /* else fall through to the case below because
-                             * iterated objects and arrays are processed in the
-                             * same way */
                         }
+                        /* fall through */
+                        /* Because iterated objects and arrays are processed in the
+                         * same way */
                     case JSON_CONTAINER_TYPE_ARRAY:
                         if (JsonLength(var) > 0)
                         {
