@@ -1,16 +1,16 @@
 /*
-   Copyright 2018 Northern.tech AS
+  Copyright 2019 Northern.tech AS
 
-   This file is part of CFEngine 3 - written and maintained by Northern.tech AS.
+  This file is part of CFEngine 3 - written and maintained by Northern.tech AS.
 
-   This program is free software; you can redistribute it and/or modify it
-   under the terms of the GNU General Public License as published by the
-   Free Software Foundation; version 3.
+  This program is free software; you can redistribute it and/or modify it
+  under the terms of the GNU General Public License as published by the
+  Free Software Foundation; version 3.
 
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
@@ -25,6 +25,7 @@
 #include <pipes.h>
 
 #include <mutex.h>
+#include <global_mutex.h>
 #include <exec_tools.h>
 #include <rlist.h>
 #include <policy.h>
@@ -33,30 +34,23 @@
 #include <signals.h>
 #include <string_lib.h>
 
-static int CfSetuid(uid_t uid, gid_t gid);
+static bool CfSetuid(uid_t uid, gid_t gid);
 
 static int cf_pwait(pid_t pid);
 
 static pid_t *CHILDREN = NULL; /* GLOBAL_X */
-static int MAX_FD = 128; /* GLOBAL_X */ /* Max number of simultaneous pipes */
+static int MAX_FD = 2048; /* GLOBAL_X */ /* Max number of simultaneous pipes */
 
 
-static bool ChildrenFDInit()
+static void ChildrenFDInit()
 {
-    if (!ThreadLock(cft_count))
+    ThreadLock(cft_count);
+    if (CHILDREN == NULL)       /* first time */
     {
-        return false;
+        CHILDREN = xcalloc(MAX_FD, sizeof(pid_t));
     }
-    else
-    {
-        if (CHILDREN == NULL)       /* first time */
-        {
-            CHILDREN = xcalloc(MAX_FD, sizeof(pid_t));
-        }
 
-        ThreadUnlock(cft_count);
-        return true;
-    }
+    ThreadUnlock(cft_count);
 }
 
 /*****************************************************************************/
@@ -143,10 +137,7 @@ static pid_t GenericCreatePipeAndFork(IOPipe *pipes)
         }
     }
 
-    if (! ChildrenFDInit())
-    {
-        return -1;
-    }
+    ChildrenFDInit();
 
     /* Create pair of descriptors to this process. */
     if (pipes[0].type && pipe(pipes[0].pipe_desc) < 0)
@@ -799,18 +790,31 @@ static int cf_pwait(pid_t pid)
 
 /*******************************************************************/
 
-/* Closes the pipe and wait()s for PID of the child,
-   in order to reap the zombies. */
+/**
+ * Closes the pipe without waiting the child.
+ *
+ * @param pp pipe to the child process
+ */
+void cf_pclose_nowait(FILE *pp)
+{
+    if (fclose(pp) == EOF)
+    {
+        Log(LOG_LEVEL_ERR,
+            "Could not close the pipe to the executed subcommand (fclose: %s)",
+            GetErrorStr());
+    }
+}
+
+/**
+ * Closes the pipe and wait()s for PID of the child,
+ * in order to reap the zombies.
+ */
 int cf_pclose(FILE *pp)
 {
     int fd = fileno(pp);
     pid_t pid;
 
-    if (!ThreadLock(cft_count))
-    {
-        fclose(pp);
-        return -1;
-    }
+    ThreadLock(cft_count);
 
     if (CHILDREN == NULL)       /* popen hasn't been called */
     {
@@ -847,11 +851,7 @@ int cf_pclose(FILE *pp)
 
 int cf_pclose_full_duplex_side(int fd)
 {
-    if (!ThreadLock(cft_count))
-    {
-        close(fd);
-        return -1;
-    }
+    ThreadLock(cft_count);
 
     if (CHILDREN == NULL)       /* popen hasn't been called */
     {
@@ -879,19 +879,7 @@ int cf_pclose_full_duplex_side(int fd)
 /* We are assuming that read_fd part will be always open at this point. */
 int cf_pclose_full_duplex(IOData *data)
 {
-    if (!ThreadLock(cft_count))
-    {
-        if (data->read_fd >= 0)
-        {
-            close(data->read_fd);
-        }
-
-        if (data->write_fd >= 0)
-        {
-            close(data->write_fd);
-        }
-        return -1;
-    }
+    ThreadLock(cft_count);
 
     if (CHILDREN == NULL)
     {
@@ -942,10 +930,7 @@ int cf_pclose_full_duplex(IOData *data)
 bool PipeToPid(pid_t *pid, FILE *pp)
 {
     int fd = fileno(pp);
-    if (!ThreadLock(cft_count))
-    {
-        return false;
-    }
+    ThreadLock(cft_count);
 
     if (CHILDREN == NULL)       /* popen hasn't been called */
     {
@@ -961,7 +946,7 @@ bool PipeToPid(pid_t *pid, FILE *pp)
 
 /*******************************************************************/
 
-static int CfSetuid(uid_t uid, gid_t gid)
+static bool CfSetuid(uid_t uid, gid_t gid)
 {
     struct passwd *pw;
 
