@@ -1,16 +1,16 @@
 /*
-   Copyright 2018 Northern.tech AS
+  Copyright 2019 Northern.tech AS
 
-   This file is part of CFEngine 3 - written and maintained by Northern.tech AS.
+  This file is part of CFEngine 3 - written and maintained by Northern.tech AS.
 
-   This program is free software; you can redistribute it and/or modify it
-   under the terms of the GNU General Public License as published by the
-   Free Software Foundation; version 3.
+  This program is free software; you can redistribute it and/or modify it
+  under the terms of the GNU General Public License as published by the
+  Free Software Foundation; version 3.
 
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
@@ -53,7 +53,11 @@ void ProcessSignalTerminate(pid_t pid)
     }
 
     sleep(1);
-
+    if (kill(pid, 0) != 0)
+    {
+        /* can no longer send signals to the process => it's dead now */
+        return;
+    }
 
     if(kill(pid, SIGTERM) == -1)
     {
@@ -62,7 +66,11 @@ void ProcessSignalTerminate(pid_t pid)
     }
 
     sleep(5);
-
+    if (kill(pid, 0) != 0)
+    {
+        /* can no longer send signals to the process => it's dead now */
+        return;
+    }
 
     if(kill(pid, SIGKILL) == -1)
     {
@@ -96,7 +104,7 @@ static bool IsProcessRunning(pid_t pid)
 
 /*************************************************************/
 
-int GetCurrentUserName(char *userName, int userNameLen)
+bool GetCurrentUserName(char *userName, int userNameLen)
 {
     char buf[GETPW_R_SIZE_MAX] = {0};
     struct passwd pwd;
@@ -119,7 +127,7 @@ int GetCurrentUserName(char *userName, int userNameLen)
 
 /*************************************************************/
 
-int IsExecutable(const char *file)
+bool IsExecutable(const char *file)
 {
     struct stat sb;
     gid_t grps[NGROUPS];
@@ -244,7 +252,7 @@ bool ShellCommandReturnsZero(const char *command, ShellType shell)
         {
             if (errno != EINTR)
             {
-                return -1;
+                return false;
             }
         }
 
